# {{ project_name }}

**Authors:** [{{ author_full_name }}](https://github.com/{{ github_username }}){% if has_additional_authors %}, {% for author in additional_authors %}{{ author }}{% if not loop.last %}, {% endif %}{% endfor %}{% endif %}

**Contact:** [{{ author_email }}](mailto:{{ author_email }})

**Description:** {{ project_description }}

--------------------------------------

[![pixi-badge](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/prefix-dev/pixi/main/assets/badge/v0.json&style=flat-square)](https://github.com/prefix-dev/pixi)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json&style=flat-square)](https://github.com/astral-sh/ruff)
[![Built with Material for MkDocs](https://img.shields.io/badge/mkdocs--material-gray?logo=materialformkdocs&style=flat-square)](https://github.com/squidfunk/mkdocs-material)

![GitHub last commit](https://img.shields.io/github/last-commit/{{ repo_location }}/{{ project_slug }}?style=flat-square)
![GitHub issues](https://img.shields.io/github/issues/{{ repo_location }}/{{ project_slug }}?style=flat-square)
![GitHub pull requests](https://img.shields.io/github/issues-pr/{{ repo_location }}/{{ project_slug }}?style=flat-square)
![GitHub contributors](https://img.shields.io/github/contributors/{{ repo_location }}/{{ project_slug }}?style=flat-square)
![GitHub release (latest by date)](https://img.shields.io/github/v/release/{{ repo_location }}/{{ project_slug }}?style=flat-square)

## Set Up

### Prerequisites

Pixi is required to run this project.
If you haven't installed it yet, [follow these instructions](https://pixi.sh/latest/)

### Installation

1. Clone this repository to your local machine
2. Navigate to the project directory
3. Set up the environment using Pixi:

```bash
pixi install
```

## Documentation

Click [here](https://{{ repo_location }}.github.io/{{ project_slug }}) to view the full documentation.
